function [T,Y] = eulers(f,a,b,ya,m)
%---------------------------------------------------------------------------
%EULERS   metodo de Euler para y' = f(t,y) com y(a) = ya.
% chamada
%   [T,Y] = eulers('f',a,b,ya,m)
% entrada
%   f    nome da function
%   a    limite inferior de [a,b]
%   b    limite superior de [a,b]
%   ya   valor inicial
%   m    numero de etapas
% Saida
%   T    solucao: vector das abscissas
%   Y    solucao: vector das ordinadas
%
% Programa retirado de: NUMERICAL METHODS: MATLAB Programs, 
% John H. Mathews 1995
%
% Metodo de Euler'.
%---------------------------------------------------------------------------

h = (b - a)/m;
T = zeros(1,m+1);
Y = zeros(1,m+1);
T(1) = a;
Y(1) = ya;
for j=1:m,
  Y(j+1) = Y(j) + h*feval(f,T(j),Y(j));
  T(j+1) = a + h*j;
end
